@@ -1,7 +1,4 @@
-#### virtualenv-commands
-#### Scripting Utilities
-
-### Copyright (c) 2009, Coptix, Inc.  All rights reserved.
+### Copyright (c) 2010, Coptix, Inc.  All rights reserved.
 ### See the LICENSE file for license terms and warranty disclaimer.
 
 """script -- Utilities for writing scripts."""
@@ -141,16 +138,4 @@ def python(*args):
     return must(current_python_interpreter(), *args)
 
 def current_python_interpreter():
-    ## Note: This is kludge; what's a better way to find the "current"
-    ## python interpreter?
-
-    ## If this script is being executed directly, use which() to find
-    ## the python interpreter.  Otherwise, assume the script is being
-    ## run through a python interpreter directly; look for the
-    ## interpreter in the environment.
-
-    path = os.environ['_']
-    if os.path.basename(path).startswith('python'):
-        return path
-    else:
-        return which('python')
+    return sys.executable
